import unittest
from password_generator.password_generator import PassGen, strongpass

class TestPassGen(unittest.TestCase):
    def test_generate_password_default_length(self):
        pg = PassGen(length=8)
        password = pg.generate_password()
        self.assertEqual(len(password), 8)

    def test_generate_password_custom_length(self):
        pg = PassGen(length=12)
        password = pg.generate_password()
        self.assertEqual(len(password), 12)

    def test_generate_password_with_no_lowercase(self):
        pg = PassGen(length=10, use_lowercase=False)
        password = pg.generate_password()
        self.assertTrue(all(char.islower() == False for char in password))

    def test_generate_password_with_no_uppercase(self):
        pg = PassGen(length=10, use_uppercase=False)
        password = pg.generate_password()
        self.assertTrue(all(char.isupper() == False for char in password))

    def test_generate_password_with_no_numbers(self):
        pg = PassGen(length=10, use_numbers=False)
        password = pg.generate_password()
        self.assertTrue(all(char.isdigit() == False for char in password))

    def test_generate_password_with_no_symbols(self):
        pg = PassGen(length=10, use_symbols=False)
        password = pg.generate_password()
        self.assertTrue(all(char not in '!@#$%^&*()' for char in password))

    def test_strongpass_default_length(self):
        password = strongpass()
        self.assertEqual(len(password), 8)

    def test_strongpass_custom_length(self):
        password = strongpass(length=12)
        self.assertEqual(len(password), 12)

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

setup(
    name='ete_pass',
    version='1.0.2',
    packages=find_packages(),
    description="A strong password generator with choosable characters and length",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author="Alireza Etezad",
    author_email="ar_etezad@yahoo.com",
    url="https://github.com/AlirezaEtezad/Password_Generator",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'click',
    ],
    entry_points={
        'console_scripts': [
            'generate-password=password_generator.password_generator:generate_password',
        ],
    },
    python_requires='>=3.6',
)



import string
import secrets
import click

class PassGen:
    def __init__(self, length, use_symbols=True, use_uppercase=True, use_lowercase=True, use_numbers=True,):
        self.length = length
        self.use_symbols = use_symbols
        self.use_uppercase = use_uppercase
        self.use_lowercase = use_lowercase
        self.use_numbers = use_numbers
        self.alphabets_small = string.ascii_lowercase if use_lowercase else ""
        self.alphabets_capital = string.ascii_uppercase if use_uppercase else ""
        self.numbers = string.digits if use_numbers else ""
        self.symbols = "!@#$%^&*()" if use_symbols else ""
        self.characters = self.alphabets_small + self.alphabets_capital + self.numbers + self.symbols

    def choose_char(self):
        return secrets.choice(self.characters)

    def generate_password(self):
        if self.length < 3:
            self.length = 3
        elif self.length > 100:
            self.length = 100

        if not self.characters:
            raise ValueError("No character types selected for password generation")

        password = []

        if self.use_lowercase:
            password.append(secrets.choice(self.alphabets_small))
        if self.use_uppercase:
            password.append(secrets.choice(self.alphabets_capital))
        if self.use_numbers:
            password.append(secrets.choice(self.numbers))
        if self.use_symbols:
            password.append(secrets.choice(self.symbols))

        while len(password) < self.length:
            password.append(self.choose_char())

        secrets.SystemRandom().shuffle(password)
        return ''.join(password[:self.length])

def strongpass(length=8 ,use_symbols=True, use_uppercase=True, use_lowercase=True, use_numbers=True) -> str:
    generator = PassGen(length, use_symbols,use_uppercase, use_lowercase, use_numbers)
    return generator.generate_password()

@click.command()
@click.option('--length', default=8, help='Length of the password.')
@click.option('--no-lowercase', is_flag=True, help='Exclude lowercase letters from the password.')
@click.option('--no-uppercase', is_flag=True, help='Exclude uppercase letters from the password.')
@click.option('--no-numbers', is_flag=True, help='Exclude numbers from the password.')
@click.option('--no-symbols', is_flag=True, help='Exclude symbols from the password.')
def generate_password(length, no_symbols, no_uppercase, no_lowercase, no_numbers):
    """Generate a strong password."""
    password = strongpass(length,not no_symbols, not no_uppercase, not no_lowercase, not no_numbers)
    click.echo(f"Generated password: {password}")

if __name__ == "__main__":
   generate_password()